package tech.riemann.ims.controller.platform.auth;

import org.springframework.http.HttpStatus;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.ResponseStatus;
import org.springframework.web.bind.annotation.RestController;

import club.zhcs.lina.auth.service.AuthService;
import club.zhcs.lina.auth.service.AuthUser;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.media.Schema;
import io.swagger.v3.oas.annotations.media.Schema.RequiredMode;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.AllArgsConstructor;
import lombok.Builder.Default;
import lombok.Data;
import lombok.NoArgsConstructor;
import lombok.RequiredArgsConstructor;
import lombok.experimental.Accessors;
import lombok.experimental.SuperBuilder;
import tech.riemann.ims.service.acl.IUserService;

/**
 * Auth
 *
 * @author Kerbores(kerbores@gmail.com)
 *
 * @since 2022-09-13 09:49:04
 */
@RestController
@RequiredArgsConstructor
@Tag(name = "Auth", description = "登录")
public class AuthController {

    private final AuthService authService;
    private final IUserService userService;

    @PostMapping("auth/login")
    @Operation(summary = "登录")
    public AuthUser login(@Validated @RequestBody LoginDTO login) {
        AuthUser authUser = userService.login(login);
        if (authUser != null) {
            authService.login(authUser);
        }
        return authUser;
    }

    @PostMapping("auth/logout")
    @Operation(summary = "登出")
    @ResponseStatus(HttpStatus.OK)
    public void logout() {
        authService.logout();
    }

    @GetMapping("auth/current-user")
    @Operation(summary = "当前用户")
    public AuthUser currentUser() {
        return authService.user();
    }

    @Data
    @SuperBuilder
    @Accessors(chain = true)
    @NoArgsConstructor
    @AllArgsConstructor
    @Schema(name = "LoginDTO", description = "登录实体")
    public static class LoginDTO {
        @Schema(description = "用户名", requiredMode = RequiredMode.NOT_REQUIRED)
        String userName;
        @Schema(description = "密码", requiredMode = RequiredMode.NOT_REQUIRED)
        String password;
        @Schema(description = "uuid", requiredMode = RequiredMode.NOT_REQUIRED)
        String uuid;
        @Schema(description = "验证码", requiredMode = RequiredMode.NOT_REQUIRED)
        String captcha;
        @Schema(description = "手机号", requiredMode = RequiredMode.NOT_REQUIRED)
        String mobile;
        @Default
        @Schema(description = "登录类型", requiredMode = RequiredMode.REQUIRED)
        Type type = Type.ACCOUNT;

        public enum Type {
            ACCOUNT,
            WECHAT
        }
    }

}
