package tech.riemann.ims.entity.material;

import club.zhcs.lina.utils.enums.Codebook;
import club.zhcs.lina.utils.enums.ICodeBook;
import com.baomidou.mybatisplus.annotation.EnumValue;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.fasterxml.jackson.annotation.JsonGetter;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.*;
import lombok.experimental.Accessors;
import lombok.experimental.FieldNameConstants;
import lombok.experimental.SuperBuilder;
import org.nutz.dao.entity.annotation.ColDefine;
import org.nutz.dao.entity.annotation.Column;
import org.nutz.dao.entity.annotation.Comment;
import org.nutz.dao.entity.annotation.Table;
import org.nutz.json.JsonField;
import tech.riemann.ims.entity.IdBaseEntity;

import java.io.Serial;

/**
 * @author mayong
 * @since 2025/3/2 14:07
 */
@Data
@SuperBuilder
@NoArgsConstructor
@AllArgsConstructor
@FieldNameConstants
@EqualsAndHashCode(callSuper = true)
@Accessors(chain = true)
@TableName("t_type")
@Table("t_type")
@Comment("类型")
@Schema(name = "Type", description = "类型")
public class Type extends IdBaseEntity {
    @Serial
    private static final long serialVersionUID = 1L;

    @Schema(description = "类型编码", requiredMode = Schema.RequiredMode.REQUIRED)
    @TableField("a_no")
    @Column("a_no")
    @Comment("类型编码")
    @ColDefine(notNull = true, width = 10, precision = 0)
    private String no;

    @Schema(description = "类型名称", requiredMode = Schema.RequiredMode.REQUIRED)
    @TableField("a_name")
    @Column("a_name")
    @Comment("类型名称")
    @ColDefine(notNull = true, width = 255, precision = 0)
    private String name;

    @Schema(description = "类型级别", requiredMode = Schema.RequiredMode.REQUIRED)
    @TableField("a_level")
    @Column("a_level")
    @Comment("类型级别")
    @ColDefine(notNull = true, width = 10, precision = 0)
    private Level level;

    @Schema(description = "上级类型编码", requiredMode = Schema.RequiredMode.NOT_REQUIRED)
    @TableField("a_parent_no")
    @Column("a_parent_no")
    @Comment("上级类型编码")
    @ColDefine(notNull = false, width = 10, precision = 0)
    private String parentNo;

    @Getter
    @AllArgsConstructor
    public enum Level implements ICodeBook {
        ONE("ONE", "一级"),
        TWO("TWO", "二级"),
        ;

        @EnumValue
        final String code;
        final String description;
    }

    @JsonGetter
    @JsonField
    public Codebook getLevelInfo() {
        return level == null ? null : level.build();
    }

    public void setLevelInfo(Codebook areaLevel) {
    }
}
